"""Example adapters for sxth-mind."""

from examples.habits import HabitCoachAdapter
from examples.learning import LearningAdapter
from examples.sales import SalesAdapter

__all__ = ["SalesAdapter", "HabitCoachAdapter", "LearningAdapter"]
